!------------------------------------------------------------------------------
!  T m a g   Photometric Package
!  EFOSC automatic measurement
!  @(#) $Id: EFOSCamag_mesAuto.prg,v 1.1 2003/10/26 06:27:17 ohainaut Exp $
!
!.usage
!  @@ EFOSCamag_mesAuto fits
!     fits: a EFOSC raw frame, eg  EFOSC_Imag.123.fits
!
!.purpose
!  pseudo pipeline for EFOSC photometric fields
!
!  It will read the frame in, then measure the 8 subframes
!
!.version 2003-10-24 first working version
!.history
!

!--- configuration parameters
!    uncomment one of the following blocks:
!--- for the 2p2m
!defi/loc zpArchive/c/1/72 /data/NTTOPS/pipeline_database/EFOSC

!--- local implementation
!!defi/loc zpArchive/c/1/72 /home/ohainaut/midwork
defi/loc zpArchive/c/1/72 /home/ohainaut/midwork

crea/gra 
crea/dis ? 450,950

writ/key EFOSCzp/c/1/72 {zpArchive}/EFOSCzp

defi/loc inima/c/1/72 
defi/loc i/i/1/1 0
defi/loc j/i/1/1 0

defi/loc filters/c/1/5 "UBVRI"
defi/loc colors/i/1/5 1,4,3,2,6
defi/loc plotflag/i/1/1 1
defi/loc w/r/1/3 0.,0.,0.
defi/loc ep/r/1/2 0.,0.
defi/loc archf/c/1/72 xxx

!
!-- read FITS in
!


if "{p1(1:5)}" .eq. "EFOSC" then
    inima = "ef_{p1(16:19)}_0001"
else 
    writ/out "[EFOSCamag/auto] *ERROR* this program is meant to deal with"
    writ/out "                untouched raw SuSI2 images. Use AMAG/MES instead"
    writ/out "                for other data"
    return/exit
endif



i = m$exist("{inima}.bdf")
if i .eq. 0 then
   writ/out "[EFOSCamag/auto] *info* reading file {inima} in Midas"
   indi/fit {p1} {inima}

   if "{{inima},ESO.DPR.TYPE}" .ne. "STD" then
      writ/out "{p1} not as standard field - EXIT"
      return
   endif
   

!   ccorrhead:
	WRI/DES {inima} cunit "   PIXEL                PIXEL           "
  	COPY/DD {inima} STEP {inima} STEP_RATAN
	COPY/DD {inima} START {inima} START_RATAN
!	WRI/DES {inima} STEP 1.,1.
!	WRI/DES {inima} START 1.,1.
	WRI/DES {inima} STEP 2.,2.
	WRI/DES {inima} START 2.,2.




endif

archf = "{{inima}.bdf,ARCFILE}"
@@ amag_checkfile {archf} .fits nocheck naked
archf = "zp.{outputc}"

!
!-- Measure the sub-images
!

!dbg!goto theend
! - modified for single chip
  writ/out "[EFOSCamag/auto] *info* processing Chip {i}"
  @@ amag_mesAuto {inima} 0.124 AUTO -1    !- measure
  @@ amag_checkfile t_{inima}.tbl .tbl softcheck
  if outputi .eq. 1 then
    @@ amag_exptime t_{inima}  !- correct exp.time
    @@ amag_oneZero t_{inima} EFOSC
!!    $ mv  t_{inima}.tbl {zpArchive}/{archf}_{i}.tbl
  endif
  !!  $ rm {inima}.bdf
theend:
!
!-- plot the individual zero points
!
writ/out "[EFOSCamag/auto] *info* plotting ZPs"

sele/tab {EFOSCzp} all | $ cat - > /dev/null
sort/tab {EFOSCzp} :epoch(-)
stat/tab {EFOSCzp} :epoch  | $ cat - > /dev/null
ep(1) = outputr(1)-.1
ep(2) = outputr(2)+.5


defi/loc chofx/r/1/8 10,75  !- start of the plots for each subchips 
defi/loc chofy/r/1/8 10,10  !   /8 for compatibility with WFI

do i = 1 1 ! loop on chips
   writ/out "               chip {i}"
   set/grap pmode=1 color=1 ltype=1 stype=1 ssize=3
   if i .eq. 1 then
      plot/axe {ep(1)},{ep(2)} 25,26.5 -110,-110,{chofx({i})},{chofy({i})}
   endif
   set/form i1
!   labe/gra "-{i}-" {ep(1)},26.2 ? 2 1

   do j = 1 5 ! loop on filters
      !- select the ZP for considered chip and filter
      sele/tab {EFOSCzp} :chip .eq. {i} .and. :FILTER .eq. "{filters({j}:{j})}" | $ cat - > /dev/null
     if {{EFOSCzp}.tbl,tblcontr(10)} .gt. 0 then !- if there is something to plot, plot it.

        set/grap color={colors({j})} ltype=0 stype=1 ssize=3
        over/tab {EFOSCzp} :epoch :zp
	copy/tab {EFOSCzp} wzp
	sele/tab wzp seq.eq.1 | $ cat - > /dev/null
	set/grap stype=18 ssize=1
	over/tab wzp :epoch :zp

      endif

enddo
enddo

set/grap color=1
labe/gra "EFOSC ZPs" 140,90,mm ? 3 1

set/grap color={colors(1)}
labe/gra "U" 140,80,mm ? 1 1
set/grap color={colors(2)}
labe/gra "B" 143,80,mm ? 1 1
set/grap color={colors(3)}
labe/gra "V" 146,80,mm ? 1 1
set/grap color={colors(4)}
labe/gra "R" 149,80,mm ? 1 1
set/grap color={colors(5)}
labe/gra "I" 151,80,mm ? 1 1

sele/tab {EFOSCzp} all | $ cat - > /dev/null
w = {{EFOSCzp}.tbl,:epoch,@1} 
w(2) = (w(1)-m$nint(w(1)-.5))*24.
i = w(2)
j = (w(2)-i)*60.
set/for i1

set/grap color=1
labe/gra "Last measurement:" 140,70,mm ? 1 1
labe/gra "{i}:{j} UT" 140,65,mm ? 1 1

labe/gra "x= Mod.JDay -52900." 140.,50,mm ? 1 1

!- save table in ascii
sele/tab {EFOSCzp} all
assi/prin file {zpArchive}/EFOSCzp.dat
prin/tab {EFOSCzp} ? ? ? 130
assi/prin

writ/out "[EFOSCamag/auto] *info* done."
$ echo "==============================================================================" >> t_{inima}_zp
$ cat  t_{inima}_zp
$ echo "[EFOSCamag/auto] result in >> t_{inima}_zp << and in NTTOPS/pipeline_database/EFOSC"

!---oOo---
