!-----------------------------------------------------------------------------
!  T m a g   Photometric Package
!  @(#) $Id: amag_objmes.prg,v 1.3 2003/10/26 06:27:17 ohainaut Exp $

! MODIFIED to measure profile of the object
! See also original amag_objMesProf.prg
!
!.syntax
!  @@ amag_objmes image diap_diam [pixScale]
! 

!  image: input image
!  diap_diam: *diameter* of the diaphragm: start, end, step
!         Must be INTEGER
!	  first value must start with @ or s or a
!	   @: in pix, 
!	   s: in seeing, 
!	   a: in arcsec (using p3)
!         eg: @20,50,5 (from 20 to 50 pix, step of 5pix)
!
!  pixScale: size of the pixel. If not give, assumed =1.
!
!  Method is hardcoded parameter
!      A=integ/aper | M=Mag/cir
!      A requires background measurement (HARDCODED)
!
!.PURPOSE
!  Measures an object in a frame (DESIGNED FOR *1* OBJECT)
!  stores the results in a table tm_<image>
!  with info for being processed by amag_comp
!
!  can be called by an exec/cat
!
!.version Tue Jan  9 23:12:14 2001 orh/ads creation
!.history 
!  Tue Jan  9 23:11:40 2001 orh/ads 
!-----------------------------------------------------------------------------


DEFI/PAR p1 ? I " image >"
DEFI/PAR p2 a1,10,1 ? " Diaphragm diameter start,end,step (@=pix: @12, s=seeing: s3) > "
DEFI/PAR p3 .12 N " Pixel size > "

!----
!- hardcoded parameters:

defi/loc ap_nml/r/1/1 99. ! aperture's no man's land, pixels
defi/loc ap_sky/r/1/1 10. ! aperture's sky, pixels

defi/loc mmethod/c/1/1 A  ! A=integ/aper | M=Mag/cir



!----

!- process parameters:
DEFI/LOC WC/c/1/72 {p2}
DEFI/LOC mode/c/1/1 {wc(1:1)}

if mode .ne. "@" then
if mode .ne. "a" then
if mode .ne. "s" then
	writ/out "*error* wrong diameter, must start with @ or s"
	return/exit
endif ; endif ; endif
if mode .eq. "s" then
	writ/out "*error* seeing mode not implemented in this version
	return/exit
endif


DEFI/LOC diap/i/1/3 {wc(2:)}
DEFI/LOC ap_diam/i/1/1 0.
DEFI/LOC ap_max/r/1/1 0.
DEFI/LOC pixsize/r/1/1 {p3}

!-- loc

DEFI/LOC seeing_a/R/1/1 0.
DEFI/LOC seeing_b/R/1/1 0.
DEFI/LOC inima/C/1/72 {p1}
DEFI/LOC intab/C/1/72 "XXX"
DEFI/LOC i/I/1/1 0
DEFI/LOC icount/i/1/1 0
DEFI/LOC idiap/i/1/1 0.
defi/loc w/r/1/1 -99.

!-- files
@@ amag_checkfile {p1} .bdf check naked ! = no ".bdf"
inima = outputc
intab = "tm_{inima}"

$ rm -f {intab}.tbl


if "{idimemc}" .ne. "{inima}" then
	load {inima}
endif

!==== START ===================================================================

clea/cha over

!
! get the seeing FROM THE OBJECT
!

crea/tab zero 4 1 
comp/tab zero :xstart = -15.
comp/tab zero :ystart = -15.
comp/tab zero :xend = 15.
comp/tab zero :yend = 15.

dra/rec zero.tbl
CEN/IQE {inima},zero wseeing 
comp/tab wseeing :x_coord = :xcen
comp/tab wseeing :y_coord = :ycen
draw/cross wseeing ? 10 green,0 
$$ sleep 1

STAT/TAB wseeing :AX_MAJ 
seeing_a = outputr(3)*pixsize
STAT/TAB wseeing :AX_MIN 
seeing_b = outputr(3)*pixsize

set/form f5.2
Writ/out "===SEEING: {seeing_a} {seeing_b}"


!
!
icount = 0

clea/ch ov

!-- measure the center (for further astrometry)
CENT/GAU {inima},zero w{intab}

   if mode .eq. "s" then
       writ/out "ERROR seeing option not implemented here"
       HALT
   else ; if mode .eq. "a" then
       ap_max = diap(2)/pixsize
   else
       ap_max = diap(2)
   endif; endif

! measure background for APERTURE
if mmethod .eq. "A" then
   writ/out ">>>Measure background. Median of last measure is kept"
   stat/ima ? cursor
   
   writ/des {inima} BACKGROUND/r/1/1 {outputr(8)}
   writ/out "Background set to {{inima},BACKGROUND}"


endif

!- Profile loop ===========================================================
do idiap = {diap(1)} {diap(2)} {diap(3)}
   icount = icount+1

   !
   ! compute diameter
   !

   if mode .eq. "s" then
        writ/out "ERROR seeing option not implemented here"
	HALT
      ap_diam = idiap * seeing_a/pixsize
   else ; if mode .eq. "a" then
       ap_diam = idiap/pixsize
   else ; if mode .eq. "@" then
       ap_diam = idiap
   else 
       writ/out "{mode} should be a,s,@"
   endif; endif; endif

   !-- nml
   ap_nml = (ap_max - ap_diam)/2.


   if icount .eq. 1 then
      crea/col w{intab} :ap_diam ! pix
      name/col w{intab} :ap_diam "Aperture diam. [pix]"

      crea/col w{intab} :ap_diama ! pix
      name/col w{intab} :ap_diama "Apert.diam. [arcsec]"

      crea/col w{intab} :ap_nml  ! no man's land
      name/col w{intab} :ap_nml "NoMansLand [pix]"
      crea/col w{intab} :ap_sky  ! sky annulus
      name/col w{intab} :ap_sky "Sky [pix]"
 
   endif

!!!!!! we set the position to 0.0, don't move it
!!!!!! if commented, use the seeing measurement as center
!!!!comp/tab wseeing :xcen = 0.
!!!!comp/tab wseeing :ycen = 0.
!!!!comp/tab wseeing :x_coord = 0.
!!!!comp/tab wseeing :y_coord = 0.
!!!!!!!


   !-- measure the magnitude
   
   if mmethod .eq. "M" then
   !-- MAGN/CIR
       writ/out "MAGN/CIR:  @{ap_diam},@{ap_nml},@{ap_sky}"

       MAG/CIRCL {inima},w{intab} w{intab} @{ap_diam},@{ap_nml},@{ap_sky} | $ cat - > /dev/null

       comp/tab w{intab} :ap_diam = {ap_diam}
       comp/tab w{intab} :ap_diama = {ap_diam}*{pixsize}
       comp/tab w{intab} :ap_nml = {ap_nml}
       comp/tab w{intab} :ap_sky = {ap_sky}

   else
   !-- INTE/APE
       w = ap_diam/2.
       writ/out "APERTURE:  diam- @{ap_diam}, radius- {w}"

       INTE/APE {inima},wseeing.tbl w{intab} {w}
!!       INTE/APE {inima},w{intab}.tbl w{intab} {w}
       comp/tab w{intab} :magnitude = :mag
       comp/tab w{intab} :mag_sigma = -999.
       comp/tab w{intab} :SKY = {{inima},BACKGROUND}

       comp/tab w{intab} :ap_diam = {ap_diam}
       comp/tab w{intab} :ap_diama = {ap_diam}*{pixsize}
       comp/tab w{intab} :ap_nml = -999.
       comp/tab w{intab} :ap_sky = -999.
       
       comp/tab w{intab} :xcen = :x_coord
       comp/tab w{intab} :ycen = :y_coord ! for compatibility

   endif


   ! draw the diap circle
   comp/tab wseeing :xstart = :xcen - {ap_diam}/2.
   comp/tab wseeing :ystart = :ycen - {ap_diam}/2.
   comp/tab wseeing :xend = :xcen + {ap_diam}/2.
   comp/tab wseeing :yend = :ycen + {ap_diam}/2.
   draw/cir  wseeing.tbl F N blue




   if icount .eq. 1 then
      $ cp w{intab}.tbl {intab}.tbl
   else 
      merge/tab {intab} w{intab} wtab
      $ mv wtab.tbl {intab}.tbl
   endif


enddo
! end profile loop===========================================================




!- plot sky annulus
   if mmethod .eq. "M" then
      comp/tab wseeing :xstart = :xcen - ({ap_diam}/2. + {ap_sky})
      comp/tab wseeing :ystart = :ycen - ({ap_diam}/2. + {ap_sky})
      comp/tab wseeing :xend   = :xcen + ({ap_diam}/2. + {ap_sky})
      comp/tab wseeing :yend   = :ycen + ({ap_diam}/2. + {ap_sky})
      draw/cir  wseeing.tbl F N red
   endif

!--- add generic column

crea/col {intab} :filter C*1
crea/col {intab} :epoch r*8 f15.8
name/col {intab} :xcen f8.2
name/col {intab} :ycen f8.2
comp/tab {intab} :pixsize = {pixsize}



!-------- airmass

i = m$existd(inima,"ESO.TEL.AIRM.START")
if i .eq. 1 then
  comp/tab {intab} :AIRM = ({{inima},ESO.TEL.AIRM.START}+{{inima},ESO.TEL.AIRM.END})/2.
else
  i = m$existd(inima,"o_airm")
  if i .eq. 1 then
    comp/tab {intab} :AIRM = {{inima},o_airm}
  else 
    comp/tab {intab} :AIRM = .9999999
  endif
endif

!---------- filter

i = m$existd(inima,"ESO.INS.FILT1.NAME")
if i .eq. 1 then
   comp/tab {intab} :filter = "{{inima},ESO.INS.FILT1.NAME(1:1)}"
endif
i = m$existd(inima,"ESO.INS.FILT2.NAME")
if i .eq. 1 then
   comp/tab {intab} :filter = "{{inima},ESO.INS.FILT2.NAME(1:1)}"
endif
i = m$existd(inima,"FILTER")
if i .eq. 1 then
   comp/tab {intab} :filter = "{{inima},FILTER(1:1)}"
endif



!-------- exptime

comp/tab {intab} :exp_time = {{inima},o_time(7)}

!-------- epoch
set/for   f15.8
COMP/TAB  {intab} :epoch = {{inima},O_TIME(4)}
set/for


!-------
COMP/TAB  {intab} :frame = "{inima}"

i = m$existd(inima,"IDENT")
if i .eq. 1 then
  COMP/TAB  {intab} :fr_id = "{{inima},IDENT}"
else
  COMP/TAB  {intab} :fr_id = "{inima}"
endif




i = m$existd(inima,"ESO.OBS.NAME}")
if i .eq. 1 then
  COMP/TAB  {intab} :name = "{{inima},ESO.OBS.NAME}"
else
  COMP/TAB  {intab} :name = "{inima}"
endif



comp/tab {intab} :seeing_a = {seeing_A}
comp/tab {intab} :seeing_b = {seeing_b}

crea/col {intab} :iw I2
comp/tab {intab} :iw = seq
comp/tab {intab} :ident = tochar(:iw)
dele/col {intab} :iw



set/form f5.2
defi/loc out/C/1/80 "{{intab},:name,@1} {inima} {{inima},O_TIME(4)} {{inima},o_time(7)} {{intab},:filter,@1}"
set/form f5.3
out = "{out} {{intab},:airm,@1} {{intab},:MAGNITUDE,@1}"
out = "{out} {{intab},:MAG_SIGMA,@1} {{intab},:SKY,@1}"
write/out "{out}"

set/form

assi/gra g,0
set/grap 
set/grap pmode=1

plo/tab {intab} :ap_diama :MAGNITUDE
$ rm w{intab}.tbl
