#!/bin/csh 
# usage:  phot2mag.csh  INPUT
# output: stdout
# converts a amag photometric solution summary into 
# a code snippet for amag_comp.
#
# input is a file like this
#4R 3380.598 25.961 0.001 0.091 0.0 -0.058 0.002 V-R cpc 0004
#3V 3380.559 25.791 0.012 0.125 0.0 -0.009 0.011 V-R cpc 0008
#5I 3380.566 25.492 0.024 0.051 0.0 -0.074 0.048 R-I cpc 0005
#
#output is a piece of code like this:
#DEFI/LOC zero/r/1/5  -99,-99,25.791,25.961,25.492
#DEFI/LOC zeroS/r/1/5 -99,-99,0.012,0.001,0.024
#DEFI/LOC extn/r/1/5  -99,-99,0.125,0.091,0.051
#DEFI/LOC extnS/r/1/5 -99,-99,0.0,0.0,0.0
#DEFI/LOC color/r/1/5  -99,-99,-0.009,-0.058,-0.074
#DEFI/LOC colorS/r/1/5 -99,-99,0.011,0.002,0.048
#DEFI/LOC cindexU/c/1/3 V-R
#DEFI/LOC cindexB/c/1/3 V-R
#DEFI/LOC cindexV/c/1/3 V-R
#DEFI/LOC cindexR/c/1/3 V-R
#DEFI/LOC cindexI/c/1/3 R-I
# to be included in amag/comp

set myU = `grep 1U $1 `
set myB = `grep 2B $1 `
set myV = `grep 3V $1 `
set myR = `grep 4R $1 `
set myI = `grep 5I $1 `

if ("$myU" == "") then 
    set myU = (1U 3380.598 -99 -99 -99 -99 -99 -99 V-R cpc 0004)
endif
if ("$myB" == "") then 
    set myB = (2B 3380.598 -99 -99 -99 -99 -99 -99 V-R cpc 0004)
endif
if ("$myV" == "") then 
    set myV = (3V 3380.598 -99 -99 -99 -99 -99 -99 V-R cpc 0004)
endif
if ("$myR" == "") then 
    set myR = (4R 3380.598 -99 -99 -99 -99 -99 -99 V-R cpc 0004)
endif
if ("$myI" == "") then 
    set myI = (5I 3380.598 -99 -99 -99 -99 -99 -99 V-R cpc 0004)
endif
echo "output in  $1:r.prg"
cat - > $1:r.prg <<EOF
WRIT/KEY ph_zero/r/1/5  $myU[3],$myB[3],$myV[3],$myR[3],$myI[3]
WRIT/KEY ph_zeroS/r/1/5 $myU[4],$myB[4],$myV[4],$myR[4],$myI[4]
WRIT/KEY ph_extn/r/1/5  $myU[5],$myB[5],$myV[5],$myR[5],$myI[5]
WRIT/KEY ph_extnS/r/1/5 $myU[6],$myB[6],$myV[6],$myR[6],$myI[6]
WRIT/KEY ph_color/r/1/5  $myU[7],$myB[7],$myV[7],$myR[7],$myI[7]
WRIT/KEY ph_colorS/r/1/5 $myU[8],$myB[8],$myV[8],$myR[8],$myI[8]
WRIT/KEY ph_cindexU/c/1/3 $myU[9]
WRIT/KEY ph_cindexB/c/1/3 $myB[9]
WRIT/KEY ph_cindexV/c/1/3 $myV[9]
WRIT/KEY ph_cindexR/c/1/3 $myR[9]
WRIT/KEY ph_cindexI/c/1/3 $myI[9]
EOF
